import { DatePipe } from '@angular/common';
import { Component, Input, Output, EventEmitter, NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SimpleDatePickerComponent {
    /**
     * @param {?} datePipe
     */
    constructor(datePipe) {
        this.datePipe = datePipe;
        this.dateChange = new EventEmitter();
        this.showDatePicker = false;
        this.dateValues = [];
        this.months = ["Januari", "Februari", "Maart", "April", "Mei", "Juni", "Juli", "Augustus", "September", "October", "November", "December"];
        this.days = ["Ma", "Di", "Wo", "Do", "Vr", "Za", "Zo"];
        this.daysInMonth = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.date === undefined) {
            this.date = this.datePipe.transform(new Date(), 'dd-MM-yyyy');
            this.dateFormat = "dd-MM-yyyy";
        }
        if (this.dateFormat === undefined) {
            this.dateFormat = "dd-MM-yyyy";
        }
        this.parseDate();
        //console.log('date:', this.date, ', length:', this.date.length);
        this.build();
    }
    /**
     * @return {?}
     */
    toggle() {
        this.showDatePicker = !this.showDatePicker;
    }
    /**
     * @return {?}
     */
    getYears() {
        /** @type {?} */
        var years = [];
        for (var i = this.selectedDate.getFullYear() - 10; i < this.selectedDate.getFullYear() + 10; i++) {
            years.push(i);
        }
        return years;
    }
    /**
     * @param {?} d
     * @return {?}
     */
    isSelectedDate(d) {
        if ((d.day == this.originalDate.getDate()) && (d.month - 1 == this.originalDate.getMonth()) && (d.year == this.originalDate.getFullYear())) {
            return "sdp-day-selected";
        }
        if (d.month - 1 != this.selectedDate.getMonth()) {
            return "sdp-day-condensed";
        }
        return "sdp-day";
    }
    /**
     * @private
     * @return {?}
     */
    parseDate() {
        if (this.dateFormat == undefined || this.dateFormat == "dd-MM-yyyy") {
            //console.log('DMY')
            /** @type {?} */
            var df1 = this.date.split("-", 3);
            /** @type {?} */
            var d1 = parseInt(df1[0]);
            /** @type {?} */
            var m1 = parseInt(df1[1]);
            /** @type {?} */
            var y1 = parseInt(df1[2]);
            this.selectedDate = new Date(y1, m1 - 1, d1);
            this.originalDate = new Date(this.selectedDate);
        }
        else if (this.dateFormat == "yyyy-MM-dd") {
            //console.log('YMD')
            /** @type {?} */
            var df2 = this.date.split("-", 3);
            /** @type {?} */
            var y2 = parseInt(df2[0]);
            /** @type {?} */
            var m2 = parseInt(df2[1]);
            /** @type {?} */
            var d2 = parseInt(df2[2]);
            this.selectedDate = new Date(y2, m2 - 1, d2);
            this.originalDate = new Date(this.selectedDate);
        }
    }
    /**
     * @private
     * @return {?}
     */
    build() {
        this.dateValues = [];
        /** @type {?} */
        var d = new Date(this.selectedDate.getFullYear(), this.selectedDate.getMonth(), 1);
        /** @type {?} */
        var m = d.getMonth();
        /** @type {?} */
        var y = d.getFullYear();
        /** @type {?} */
        var dow = d.getDay() == 0 ? 6 : (d.getDay() - 1);
        /** @type {?} */
        var row = [];
        if (y % 4 == 0) {
            this.daysInMonth[1] = 29;
        }
        /** @type {?} */
        var prevYear = y;
        /** @type {?} */
        var prevMonth = m - 1;
        if (prevMonth < 0) {
            prevMonth = 11;
            prevYear = prevYear - 1;
        }
        for (var k = 1; k <= dow; k++) {
            /** @type {?} */
            var r1 = {
                day: this.daysInMonth[prevMonth] - dow + k,
                month: prevMonth + 1,
                year: prevYear
            };
            row.push(r1);
        }
        for (var day = 0; day < this.daysInMonth[m]; day++) {
            /** @type {?} */
            var r2 = {
                day: (day + 1),
                month: m + 1,
                year: y
            };
            if ((day + dow + 1) % 7 == 0) {
                row.push(r2);
                this.dateValues.push({ record: row });
                row = [];
            }
            else {
                row.push(r2);
            }
        }
        /** @type {?} */
        var nextMonth = m + 1;
        /** @type {?} */
        var nextYear = y;
        if (m > 11) {
            nextYear = y + 1;
        }
        /** @type {?} */
        var last = row.length;
        for (var l = 0; l < 7 - last; l++) {
            /** @type {?} */
            var r3 = {
                day: l + 1,
                month: nextMonth + 1,
                year: nextYear
            };
            row.push(r3);
        }
        //console.log("row length:", row.length);
        this.dateValues.push({ record: row });
    }
    /**
     * @param {?} d
     * @return {?}
     */
    selectDate(d) {
        //console.log('you selected :', d);
        this.date = this.datePipe.transform(new Date(d.year, d.month - 1, d.day), this.dateFormat);
        this.parseDate();
        this.showDatePicker = false;
        this.dateChange.emit(this.date);
    }
    /**
     * @param {?} field
     * @param {?} value
     * @return {?}
     */
    onDateChange(field, value) {
        //console.log(field, ', ', value);
        if (field === 'month') {
            this.selectedDate.setMonth(value);
        }
        else if (field === 'year') {
            this.selectedDate.setFullYear(value);
        }
        this.build();
        //console.log('selectedDate:', this.selectedDate);
        //console.log('originalDate:', this.originalDate);
    }
}
SimpleDatePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'simple-date-picker',
                template: "<div *ngIf=\"showDatePicker\" class=\"sdp\">\r\n    <div class=\"sdp-header\">\r\n        <div>\r\n            <span></span>\r\n        </div>\r\n        <div>\r\n            <select class=\"sdp-select\" #m (change)=\"onDateChange('month', m.value)\">\r\n        <option [selected]=\"i == selectedDate.getMonth()\" value=\"{{i}}\" *ngFor=\"let month of months; let i = index;\">{{month}}\r\n        </option>\r\n      </select>\r\n        </div>\r\n        <div>\r\n            <select class=\"sdp-select\" #y (change)=\"onDateChange('year', y.value)\">\r\n        <option [selected]=\"year == selectedDate.getFullYear()\" value=\"{{year}}\" *ngFor=\"let year of getYears()\">{{year}}</option>\r\n      </select>\r\n        </div>\r\n        <div>\r\n            <span></span>\r\n        </div>\r\n    </div>\r\n    <div class=\"sdp-weekday-header\">\r\n        <div class=\"sdp-weekday-body\">\r\n            <div *ngFor=\"let i of [0, 1, 2, 3, 4, 5, 6]\">\r\n                <div class=\"sdp-weekday\">{{days[i]}}</div>\r\n            </div>\r\n        </div>\r\n    </div>\r\n    <div class=\"sdp-calendar\">\r\n        <div class=\"sdp-week\" *ngFor=\"let row of dateValues; let i = index\">\r\n            <div *ngFor=\"let col of row.record; let x = index;\">\r\n                <div [className]=\"isSelectedDate(col)\" (click)=\"selectDate(col)\">{{col.day}}</div>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>",
                providers: [
                    DatePipe
                ],
                styles: [".sdp{margin-top:3px;width:315px;background-color:#f5f5f5;border:1px solid #d3d3d3}.sdp-header{display:inline-flex;background-color:#f5f5f5;width:100%}.sdp-weekday-header{border-bottom:1px solid #d3d3d3}.sdp-weekday-body{color:#17a2b8;font-style:italic;font-size:21px;display:flex;margin-left:8px}.sdp-weekday{margin-right:5px;width:38px;text-align:center}.sdp-calendar{background-color:#fff;text-align:center}.sdp-week{margin-top:2px;margin-bottom:2px;display:flex;margin-left:8px;background-color:#fff}.sdp-day{font-size:22px;width:38px;margin-right:5px;color:#000;text-align:center}.sdp-day:hover{background-color:beige;cursor:pointer}.sdp-day-selected{font-size:22px;width:38px;margin-right:5px;color:#000;text-align:center;background-color:azure;border:1px solid red}.sdp-day-condensed{font-size:22px;width:38px;margin-right:5px;color:#a9a9a9;font-style:italic;text-align:center;cursor:pointer}.sdp-day-condensed:hover{font-size:22px;width:38px;margin-right:5px;color:#a9a9a9;background-color:#dedede;font-style:italic;text-align:center;cursor:pointer}.sdp-select{width:120px;margin:10px 10px 10px 21px;border-radius:2px;font-size:20px}"]
            }] }
];
/** @nocollapse */
SimpleDatePickerComponent.ctorParameters = () => [
    { type: DatePipe }
];
SimpleDatePickerComponent.propDecorators = {
    date: [{ type: Input }],
    dateChange: [{ type: Output }],
    dateFormat: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SimpleDatePickerModule {
}
SimpleDatePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    SimpleDatePickerComponent
                ],
                imports: [
                    BrowserModule
                ],
                exports: [
                    SimpleDatePickerComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { SimpleDatePickerComponent, SimpleDatePickerModule };

//# sourceMappingURL=simply-date-picker.js.map